<?php
/**
 * Invoice Ninja (https://invoiceninja.com).
 *
 * @link https://github.com/invoiceninja/invoiceninja source repository
 *
 * @copyright Copyright (c) 2022. Invoice Ninja LLC (https://invoiceninja.com)
 *
 * @license https://www.elastic.co/licensing/elastic-license
 */

namespace App\Http\Requests\Report;

use App\Http\Requests\Request;

class GenericReportRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize() : bool
    {
        return auth()->user()->isAdmin();
    }

    public function rules()
    {
        return [
            'start_date' => 'string|date',
            'end_date' => 'string|date',
            'date_key' => 'string',
            'date_range' => 'sometimes|string',
            'report_keys' => 'present|array',
            'send_email' => 'required|bool',
        ];
    }

    public function prepareForValidation()
    {
        $input = $this->all();

        if(!array_key_exists('date_range', $input))
            $input['date_range'] = 'all';

        if(!array_key_exists('report_keys', $input))
            $input['report_keys'] = [];

        if(!array_key_exists('send_email', $input))
            $input['send_email'] = true;

        $this->replace($input);
    }
}
